@@ -81,75 +81,76 @@ class EmitSeries(object):
         if not task.is_rerun:
             self.try_next_season = {}
         entries = []
-        for seriestask in task.session.query(SeriesTask).filter(SeriesTask.name == task.name).all():
-            series = seriestask.series
-            if not series:
-                # TODO: How can this happen?
-                log.debug('Found SeriesTask item without series specified. Cleaning up.')
-                task.session.delete(seriestask)
-                continue
+        with Session() as session:
+            for seriestask in session.query(SeriesTask).filter(SeriesTask.name == task.name).all():
+                series = seriestask.series
+                if not series:
+                    # TODO: How can this happen?
+                    log.debug('Found SeriesTask item without series specified. Cleaning up.')
+                    session.delete(seriestask)
+                    continue
 
-            if series.identified_by not in ['ep', 'sequence']:
-                if not task.is_rerun:
-                    log.verbose('Can only emit ep or sequence based series. '
-                                '`%s` is identified_by %s' %
-                                (series.name, series.identified_by or 'auto'))
-                continue
+                if series.identified_by not in ['ep', 'sequence']:
+                    if not task.is_rerun:
+                        log.verbose('Can only emit ep or sequence based series. '
+                                    '`%s` is identified_by %s' %
+                                    (series.name, series.identified_by or 'auto'))
+                    continue
 
-            low_season = 0 if series.identified_by == 'ep' else -1
+                low_season = 0 if series.identified_by == 'ep' else -1
 
-            latest_season = get_latest_release(series)
-            if latest_season:
-                latest_season = latest_season.season
-            else:
-                latest_season = low_season + 1
+                latest_season = get_latest_release(series)
+                if latest_season:
+                    latest_season = latest_season.season
+                else:
+                    latest_season = low_season + 1
 
-            if self.try_next_season.get(series.name):
-                entries.append(self.search_entry(series, latest_season + 1, 1, task))
-            else:
-                for season in xrange(latest_season, low_season, -1):
-                    log.debug('Adding episodes for season %d' % season)
-                    check_downloaded = not config.get('backfill')
-                    latest = get_latest_release(series, season=season, downloaded=check_downloaded)
-                    if series.begin and (not latest or latest < series.begin):
-                        entries.append(self.search_entry(series, series.begin.season, series.begin.number, task))
-                    elif latest:
-                        start_at_ep = 1
-                        episodes_this_season = (task.session.query(Episode).
-                                                filter(Episode.series_id == series.id).
-                                                filter(Episode.season == season))
-                        if series.identified_by == 'sequence':
-                            # Don't look for missing too far back with sequence shows
-                            start_at_ep = max(latest.number - 10, 1)
-                            episodes_this_season = episodes_this_season.filter(Episode.number >= start_at_ep)
-                        latest_ep_this_season = episodes_this_season.order_by(desc(Episode.number)).first()
-                        downloaded_this_season = (episodes_this_season.join(Episode.releases).
-                                                filter(Release.downloaded == True).all())
-                        # Calculate the episodes we still need to get from this season
-                        if series.begin and series.begin.season == season:
-                            start_at_ep = max(start_at_ep, series.begin.number)
-                        eps_to_get = range(start_at_ep, latest_ep_this_season.number + 1)
-                        for ep in downloaded_this_season:
-                            try:
-                                eps_to_get.remove(ep.number)
-                            except ValueError:
-                                pass
-                        entries.extend(self.search_entry(series, season, x, task, rerun=False) for x in eps_to_get)
-                        # If we have already downloaded the latest known episode, try the next episode
-                        if latest_ep_this_season.releases:
-                            entries.append(self.search_entry(series, season, latest_ep_this_season.number + 1, task))
-                    else:
-                        if config.get('from_start') or config.get('backfill'):
-                            entries.append(self.search_entry(series, season, 1, task))
+                if self.try_next_season.get(series.name):
+                    entries.append(self.search_entry(series, latest_season + 1, 1, task))
+                else:
+                    for season in xrange(latest_season, low_season, -1):
+                        log.debug('Adding episodes for season %d' % season)
+                        check_downloaded = not config.get('backfill')
+                        latest = get_latest_release(series, season=season, downloaded=check_downloaded)
+                        if series.begin and (not latest or latest < series.begin):
+                            entries.append(self.search_entry(series, series.begin.season, series.begin.number, task))
+                        elif latest:
+                            start_at_ep = 1
+                            episodes_this_season = (session.query(Episode).
+                                                    filter(Episode.series_id == series.id).
+                                                    filter(Episode.season == season))
+                            if series.identified_by == 'sequence':
+                                # Don't look for missing too far back with sequence shows
+                                start_at_ep = max(latest.number - 10, 1)
+                                episodes_this_season = episodes_this_season.filter(Episode.number >= start_at_ep)
+                            latest_ep_this_season = episodes_this_season.order_by(desc(Episode.number)).first()
+                            downloaded_this_season = (episodes_this_season.join(Episode.releases).
+                                                    filter(Release.downloaded == True).all())
+                            # Calculate the episodes we still need to get from this season
+                            if series.begin and series.begin.season == season:
+                                start_at_ep = max(start_at_ep, series.begin.number)
+                            eps_to_get = range(start_at_ep, latest_ep_this_season.number + 1)
+                            for ep in downloaded_this_season:
+                                try:
+                                    eps_to_get.remove(ep.number)
+                                except ValueError:
+                                    pass
+                            entries.extend(self.search_entry(series, season, x, task, rerun=False) for x in eps_to_get)
+                            # If we have already downloaded the latest known episode, try the next episode
+                            if latest_ep_this_season.releases:
+                                entries.append(self.search_entry(series, season, latest_ep_this_season.number + 1, task))
                         else:
-                            if not task.is_rerun:
-                                log.verbose('Series `%s` has no history. Set begin option, '
-                                            'or use CLI `series begin` '
-                                            'subcommand to set first episode to emit' % series.name)
-                            break
+                            if config.get('from_start') or config.get('backfill'):
+                                entries.append(self.search_entry(series, season, 1, task))
+                            else:
+                                if not task.is_rerun:
+                                    log.verbose('Series `%s` has no history. Set begin option, '
+                                                'or use CLI `series begin` '
+                                                'subcommand to set first episode to emit' % series.name)
+                                break
 
-                    if not config.get('backfill'):
-                        break
+                        if not config.get('backfill'):
+                            break
 
         return entries
 
