@@ -137,6 +137,11 @@ class TransmissionBase(object):
             raise plugin.PluginError('Transmissionrpc module version 0.11 or higher required.', log)
         if [int(part) for part in transmissionrpc.__version__.split('.')] < [0, 11]:
             raise plugin.PluginError('Transmissionrpc module version 0.11 or higher required, please upgrade', log)
+        """ 
+        Mark rpc client for garbage collector so every task can start 
+        a fresh new according its own config - fix to bug #2804
+        """
+        self.client = None
         config = self.prepare_config(config)
         if config['enabled']:
             if task.options.test:
@@ -598,7 +603,7 @@ class PluginTransmissionClean(TransmissionBase):
         advanced.accept('boolean', key='transmission_seed_limits')
         advanced.accept('boolean', key='delete_files')
         return root
-
+    
     def on_task_exit(self, task, config):
         config = self.prepare_config(config)
         if not config['enabled'] or task.options.learn:
